@@ -3,19 +3,18 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 our @EXPORT;
 
 {
     my @origs = qw(
         insert
-        search
         single
-        search_by_sql
         single_by_sql
-        search_named
         single_named
+        search
+        search_named
     );
     my $suffix = '_hashref';
 
@@ -29,8 +28,20 @@ our @EXPORT;
             $self->$orig(@_);
         };
     }
+    push @EXPORT, qw(
+        search_by_sql_hashref
+    );
 }
 
+sub search_by_sql_hashref {
+    my ($self, $sql, $bind, $table_name) = @_;
+
+    wantarray and return $self->dbh->selectall_array($sql, +{ Slice => +{} }, @$bind);
+    local $self->{suppress_row_objects} = 1;
+    $self->search_by_sql($sql, $bind, $table_name);
+}
+
+
 1;
 __END__
 
@@ -38,7 +49,7 @@ __END__
 
 =head1 NAME
 
-Teng::Plugin::TmpSuppressRowObjects - add methods with temporary use of suppress_row_objects
+Teng::Plugin::TmpSuppressRowObjects - add methods with temporaly use of suppress_row_objects
 
 =head1 SYNOPSIS
 
@@ -51,19 +62,19 @@ Teng::Plugin::TmpSuppressRowObjects - add methods with temporary use of suppress
 
     #  In case suppress_row_objects = 0 ...
     my $teng = Your::Model->new(dbh => $dbh, suppress_row_objects => 0);
-    my $row;
+    my @rows;
 
     #  same usage with original 'search'
-    $row = $teng->search_hashref(test_table => +{ id => 100 });     #  $row is hashref
+    @rows = $teng->search_hashref(test_table => +{ id => 100 });     #  elements in @rows are hashref
 
     #  does not affect original 'search'
-    $row = $teng->search(test_table => +{ id => 100 });     #  $row is row object
+    @rows = $teng->search(test_table => +{ id => 100 });     #  elements in @rows are row object
 
 
 =head1 DESCRIPTION
 
-This plugin adds some methods, which suppress generating row objects, even when C<suppress_row_objects> is 0.
-It is helpful when we want to use row objects in default, but temporarily use hashref to improve performance.
+This plugin adds some methods, which return hashref as a result, rather than row objects, even when C<suppress_row_objects> is 0.
+It is useful when we want row objects as default, and lightweight hashref in some cases to improve performance.
 
 
 =head1 METHODS
